--------------------------------------------------------------------------
-- WhoTip.lua 
--------------------------------------------------------------------------

local resultSuffix = string.sub(string.format(WHO_NUM_RESULTS, 1), 3).."$"
local nameWaiting = nil

local function getClassColor(class)
	for k,v in next, LOCALIZED_CLASS_NAMES_MALE do
		if class == v then
			local color = RAID_CLASS_COLORS[k]
			return string.format("%02x%02x%02x", color.r * 255, color.g * 255, color.b * 255)
		end
	end
	return "808080"
end

local function WhoTip_SetItemRef(link, text)
	if (string.sub(link, 1, 6) == "player") then
		local name = string.match(link, "^player:(.-):")
		if ( name and (string.len(name) > 0) ) then
			if ( IsShiftKeyDown() ) then
				nameWaiting = name
			end
		end
	end
end

local function ShowTip()
	local numWhos, totalCount = GetNumWhoResults()
	local name, guild, level, race, class, zone, group
	if (numWhos > 0) then
		for i = 1, numWhos do
			name, guild, level, race, class, zone, group = GetWhoInfo(i)
			if (name == nameWaiting) then
				break
			end
		end
	else
		return
	end
	
	if WhoTipDB.atMouse then
		GameTooltip:SetOwner(UIParent, "ANCHOR_CURSOR")
	else
		GameTooltip_SetDefaultAnchor(GameTooltip, UIParent);
	end
	
	local levelColor = GetQuestDifficultyColor(level)
	levelColor = levelColor and string.format("%02x%02x%02x", levelColor.r * 255, levelColor.g * 255, levelColor.b * 255) or "c0c0c0"
	local classColor = getClassColor(class)
	
	GameTooltip:AddLine(string.format("|cff%s%s|r", classColor, name))
	GameTooltip:AddLine(string.format("|cff%s%d|r |cffffffff%s|r |cff%s%s|r", levelColor, level, race, classColor, class))
	if (guild ~= "") then
		GameTooltip:AddLine(string.format("<%s>", guild), .1, 1, .1)
	end
	GameTooltip:AddLine(zone, 1, .82, 0)
	GameTooltip:Show()
end

local f = CreateFrame("Frame")
f:SetScript("OnEvent", function(self, event, arg1)
	if (event == "CHAT_MSG_SYSTEM") then
		if (nameWaiting) then
			if (arg1 == string.format(WHO_NUM_RESULTS, 0)) then
				nameWaiting = nil
			elseif (string.find(arg1, resultSuffix)) then
				ShowTip()
				nameWaiting = nil
			end
		end
	elseif (event == "ADDON_LOADED" and arg1 == "WhoTip") then
		self:UnregisterEvent("ADOON_LOADED")
		WhoTipDB = WhoTipDB or { atMouse = false }
		self:RegisterEvent("CHAT_MSG_SYSTEM")
		hooksecurefunc("SetItemRef", WhoTip_SetItemRef)
	end
end)
f:RegisterEvent("ADDON_LOADED")

SLASH_WHOTIP1 = "/whotip"
SlashCmdList["WHOTIP"] = function(input)
	WhoTipDB.atMouse = not WhoTipDB.atMouse
	DEFAULT_CHAT_FRAME:AddMessage(string.format("|cff33ff99WhoTip|r: Tooltip anchor: %s", WhoTipDB.atMouse and "Cursor" or "Default"))
end

